@@ -18,12 +18,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-css-menu.c,v 1.9 2004/12/13 18:25:17 chpe Exp $
+ *  $Id: ephy-css-menu.c,v 1.10 2005/01/13 16:15:49 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-css-menu.h"
 
